@@ -1,4 +1,4 @@
-from __init__ import *
+from .__init__ import *
 
 if __name__=='__main__':
     trace = Tracer()
